@@ -345,6 +345,19 @@ class BaseRunLogStore:
         """
         raise NotImplementedError
 
+    def update_run_log_status(self, run_id: str, status: str):
+        """
+        Updates the status of the Run Log defined by the run_id
+
+        Args:
+            run_id (str): The run_id of the run
+            status (str): The new status of the run
+        """
+        logger.info(f'Updating status of run_id {run_id} to {status}')
+        run_log = self.get_run_log_by_id(run_id, full=False)
+        run_log.status = status
+        self.put_run_log(run_log)
+
     def get_parameters(self, run_id: str, **kwargs) -> dict:  # pylint: disable=unused-argument
         """
         Get the parameters from the Run log defined by the run_id
